@@ -6,7 +6,6 @@
 */
 
 
-
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <osso-log.h>
@@ -15,43 +14,22 @@
 
 #include <sharing-http.h>
 #include <sharing-plugin-interface.h>
-/* #include <sharing-service-option.h> */
 #include <sharing-entry.h>
 #include <sharing-tag.h>
+#ifdef WITH_ALBUM_SUPPORT
+#include <sharing-service-option.h>
+#endif /* WITH_ALBUM_SUPPORT */
+
 
 #include "picasa_post.h"
 #include "picasa_http.h"
 #include "picasa_xml.h"
 
 
-/**
-   HTTP_RES_CODE_OFFSET_C
-*/
-#define HTTP_RES_CODE_OFFSET_C 9
-/**
-   HTTP_RES_ERR_OFFSET_C
-*/
-#define HTTP_RES_ERR_OFFSET_C 6
-/**
-   LOGIN_URL_C
-*/
-#define LOGIN_URL_C "https://www.google.com/accounts/ClientLogin"
-/**
-   ALBUM_URL_C
-*/
-#define FEED_URL_C "http://picasaweb.google.com/data/feed/api/user/default"
-/**
-   SERVICE_C
-*/
-#define SERVICE_C "lh2"
-/**
-   MAPS_URL_C
-*/
-#define MAPS_URL_C "http://maps.google.com/maps/geo?"
-
-
 /** Globals **/
 
+/* TODO: get rid of globals */
+
 /**
    g_response_buffer
 */
@@ -182,7 +160,7 @@ picasa_post_convert_http_error (http_request_state_t state) {
   return status;
 }
 
-#if 0
+#ifdef WITH_ALBUM_SUPPORT
 /**
    picasa_post_convert_update_options
 */
@@ -209,7 +187,7 @@ picasa_post_convert_update_options (gint status) {
 
   return result;
 }
-#endif
+#endif /* WITH_ALBUM_SUPPORT */
 
 
 /**
@@ -310,7 +288,7 @@ picasa_post_convert_send_response (picasa_post_response_t res) {
 }
 
 /**
-  picasa_post_parse_login_response
+  picasa_post_parse_response
 */
 static picasa_post_response_t
 picasa_post_parse_response (picasa_post_progress_data_t *data,
@@ -329,8 +307,10 @@ picasa_post_parse_response (picasa_post_progress_data_t *data,
   gchar *tmp = (gchar*)g_response_buffer->str;
   gint count = 0;
   guint offset = 0;
+#ifdef WITH_ALBUM_SUPPORT
   GSList *albums = NULL;
   gboolean success = FALSE;
+#endif /* WITH_ALBUM_SUPPORT */
   picasa_post_response_t res = { 0, NULL };
 
   tokens = g_strsplit_set ((gchar*)g_response_buffer->str,
@@ -358,16 +338,18 @@ picasa_post_parse_response (picasa_post_progress_data_t *data,
 
     if (g_str_has_prefix (iter, "<?xml")) {
       ULOG_DEBUG_L ("%s: Body found", fn);
-      if (type == RES_GET_ALBUMS) {
-	albums = picasa_xml_parse_album_response (iter);
-	ULOG_DEBUG_L ("%s: albums parsed (%0X)", 
-		      fn, (guint)albums);
-      }
-      else if (type == RES_UPLOAD) {
+      if (type == RES_UPLOAD) {
 	g_photo_url = picasa_xml_parse_upload_response (iter);
 	ULOG_DEBUG_L ("%s: uploaded photo id parsed (%s)", 
 		      fn, g_photo_url);
       }
+#ifdef WITH_ALBUM_SUPPORT
+      else if (type == RES_GET_ALBUMS) {
+	albums = picasa_xml_parse_album_response (iter);
+	ULOG_DEBUG_L ("%s: albums parsed (%0X)", 
+		      fn, (guint)albums);
+      }
+#endif /* WITH_ALBUM_SUPPORT */
       else if (type == RES_GET_COORDINATES) {
 	res.msg = picasa_xml_parse_gps_response ((tmp+(offset+count)));
 	ULOG_DEBUG_L ("%s: coordinates parsed = %s", 
@@ -390,7 +372,7 @@ picasa_post_parse_response (picasa_post_progress_data_t *data,
 
   }
   
-#if 0
+#ifdef WITH_ALBUM_SUPPORT
   if (albums != NULL && res.code == HTTP_OK) {
     ULOG_DEBUG_L ("%s: setting up account option values (%d) to account %s", 
 		  fn, g_slist_length (albums), 
@@ -407,7 +389,7 @@ picasa_post_parse_response (picasa_post_progress_data_t *data,
     sharing_service_option_values_free (albums);
     
   }
-#endif
+#endif /* WITH_ALBUM_SUPPORT */
   
   g_strfreev (tokens);
 
@@ -483,8 +465,7 @@ picasa_post_progress (void *clientp,
    picasa_post_login
 */
 static picasa_post_response_t
-picasa_post_login (http_session_t session,
-		   ConIcConnection *con,
+picasa_post_login (ConIcConnection *con,
 		   picasa_post_progress_data_t *data) {
   
 #ifdef DEBUG
@@ -492,7 +473,7 @@ picasa_post_login (http_session_t session,
 #endif
 
   gint status = 0;
-  picasa_post_response_t res = { GENERAL_ERROR, NULL };
+  picasa_post_response_t res = { 0, NULL };
 
   gchar *uname = sharing_account_get_param (data->account, "username");
   gchar *passwd = sharing_account_get_param (data->account, "password");
@@ -501,6 +482,7 @@ picasa_post_login (http_session_t session,
 
   if (!http) {
     ULOG_ERR_L ("%s: failed to allocate new http request, aborting upload",fn);
+    res.code = GENERAL_ERROR;
     return res;
   }
 
@@ -519,14 +501,13 @@ picasa_post_login (http_session_t session,
 				   g_response_buffer);
   
   picasa_http_set_connection (http, con);
-  /* picasa_http_set_progress_cb (http, picasa_post_progress, data); */
 
   /* send http post */
   ULOG_DEBUG_L ("%s: Sending post to %s",fn,LOGIN_URL_C);
 
   *data->dead_mans_switch = FALSE;
 
-  status = picasa_http_send (session, http, POST);
+  status = picasa_http_send (http, POST);
 
   *data->dead_mans_switch = FALSE;
   
@@ -551,13 +532,12 @@ picasa_post_login (http_session_t session,
 }
 
 
-#if 0
+#ifdef WITH_ALBUM_SUPPORT
 /**
   picasa_post_get_albums
 */
 static picasa_post_response_t 
-picasa_post_get_albums (http_session_t session,
-			ConIcConnection *con,
+picasa_post_get_albums (ConIcConnection *con,
 			picasa_post_progress_data_t *data) {
 
 #ifdef DEBUG
@@ -616,14 +596,13 @@ picasa_post_get_albums (http_session_t session,
   
   return res;
 }
-#endif
+#endif /* WITH_ALBUM_SUPPORT */
 
 /**
   picasa_post_upload_item
 */
 static picasa_post_response_t
-picasa_post_upload_item (http_session_t session, 
-			 SharingEntryMedia *media,
+picasa_post_upload_item (SharingEntryMedia *media,
 			 ConIcConnection *con,
 			 picasa_post_progress_data_t *data) {
   
@@ -633,17 +612,17 @@ picasa_post_upload_item (http_session_t session,
 
   gint status = 0;
   picasa_post_response_t res = { 0, NULL };
-  gchar *metadata, *tag_entry = NULL;
-  gchar *length = NULL;
+  gchar *metadata = NULL;
 
-  /* GSList *tags = (GSList*)sharing_entry_media_get_tags (media); */
   gchar *mime = sharing_entry_media_get_mime (media);
-  guint64 size = sharing_entry_media_get_size (media);
-  gchar *filename = sharing_entry_media_get_filename (media);
   gchar *title = sharing_entry_media_get_title (media);
   gchar *desc = (gchar*)sharing_entry_media_get_desc (media);
 
-  gchar *album_id = "default"; /* (gchar*)sharing_entry_get_option (data->entry, "albums"); */
+#ifdef WITH_ALBUM_SUPPORT
+  gchar *album_id = (gchar*)sharing_entry_get_option (data->entry, "albums");
+#else
+  gchar *album_id = "default";
+#endif /* WITH_ALBUM_SUPPORT */
   
   gchar *url = g_strconcat (FEED_URL_C, "/albumid/", album_id, NULL);
   gchar *auth = g_strconcat ("GoogleLogin auth=", g_auth, NULL);
@@ -663,80 +642,26 @@ picasa_post_upload_item (http_session_t session,
   picasa_http_add_header_data (http, "GData-Version", "2");
   picasa_http_add_header_data (http, "Authorization", auth);
 
-  if (title == NULL) { title = filename; }
+  if (title == NULL) { 
+    title = sharing_entry_media_get_filename (media); 
+  }
 
   metadata = picasa_xml_create_metadata_entry (title, desc);
   
-#if 0 /* testing how to upload image with all metadata at once */
-  metadata = g_strdup_printf ("<?xml version=\"1.0\"?>\n"
-			      "<entry xmlns=\"http://www.w3.org/2005/Atom\"\n"
-			      "xmlns:media=\"http://search.yahoo.com/mrss/\"\n"
-			      "xmlns:georss=\"http://www.georss.org/georss\"\n"
-			      "xmlns:gphoto=\"http://schemas.google.com/photos/2007\"\n"
-			      "xmlns:gml=\"http://www.opengis.net/gml\">\n"
-			      "<title>plz-to-love-realcat.jpg</title>\n"
-			      "<summary>Real cat wants attention too.</summary>\n"
-			      "<gphoto:location>Finland, Helsinki, Ruoholahti</gphoto:location>"
-			      "<media:group>\n"
-			      /*
-			      "<media:title type=\"plain\">new_title</media:title>\n"
-			      "<media:description type=\"plain\">new_description</media:description>\n"
-			      */
-			      "<media:keywords>tag, tag3</media:keywords>\n"
-			      "</media:group>\n"
-			      "<georss:where>\n"
-			      "<gml:Point>\n"
-			      "<gml:pos>35.669998 139.770004</gml:pos>\n"
-			      "</gml:Point>\n"
-			      "</georss:where>\n"
-			      "<category scheme=\"http://schemas.google.com/g/2005#kind\"\n"
-			                "term=\"http://schemas.google.com/photos/2007#photo\"/>"
-			      "</entry>\n");
-#endif
-
-  if (metadata != NULL) {
-
-    picasa_http_add_post_data_with_type (http, metadata, "application/atom+xml");
-
-    picasa_http_add_bin_file (http, sharing_entry_media_get_localpath (media),
-			      NULL, mime);
-    g_free (metadata); 
-    g_free (tag_entry);
-
-    /*
-    picasa_http_add_header_data (http, "Content-Type", 
-                                 "multipart/related; boundary=\"RANDOM_BOUNDRY\"");
-    picasa_http_append_prefix (http, "\n--RANDOM_BOUNDRY\n"); 
-    picasa_http_append_prefix (http, "Content-Type: application/atom+xml\n\n"); 
-    picasa_http_append_prefix (http, metadata); 
-    picasa_http_append_prefix (http, "--RANDOM_BOUNDRY\n"); 
-    picasa_http_append_prefix (http, "Content-Type: "); 
-    picasa_http_append_prefix (http, mime); 
-    picasa_http_append_prefix (http, "\n\n"); 
-    picasa_http_set_bin_file (http,  
-			      sharing_entry_media_get_localpath (media), 
-			      size); 
-    picasa_http_append_suffix (http, "\n--RANDOM_BOUNDRY--\n"); 
-    length = g_strdup_printf("%d", picasa_http_get_body_length (http)); 
-    ULOG_DEBUG_L ("%s: total length = %d", fn, picasa_http_get_body_length (http)); 
-    picasa_http_add_header_data (http, "Content-Length", length);
-    */
-
-    picasa_http_add_header_data (http, "MIME-version", "1.0");
-    picasa_http_add_header_data (http, "Content-Type", "multipart/related");
-
-    /* ULOG_DEBUG_L ("%s: multipart prefix = %s", fn, (http->prefix).data->str); */
-
-  } else {
-    picasa_http_add_header_data (http, "Content-Type", mime);
-    length = g_strdup_printf("%lu", (unsigned long int)size);
-    picasa_http_add_header_data (http, "Content-Length", length);
-    picasa_http_add_header_data (http, "Slug", filename);
-
-    picasa_http_set_bin_file (http, 
-			      sharing_entry_media_get_localpath (media),
-			      size);
+  if (metadata == NULL) {
+    ULOG_ERR_L ("%s: failed to create metadata entry", fn);
+    res.code = GENERAL_ERROR;
+    return res;
   }
+
+  picasa_http_add_post_data_with_type (http, metadata, "application/atom+xml");
+  g_free (metadata); 
+  
+  picasa_http_add_bin_file (http, sharing_entry_media_get_localpath (media),
+			    NULL, mime);
+
+  picasa_http_add_header_data (http, "MIME-version", "1.0");
+  picasa_http_add_header_data (http, "Content-Type", "multipart/related"); 
   
   picasa_post_init_response_buffer ();
   
@@ -753,7 +678,7 @@ picasa_post_upload_item (http_session_t session,
 
   *data->dead_mans_switch = FALSE;
 
-  status = picasa_http_send (session, http, POST);
+  status = picasa_http_send (http, POST);
 
   *data->dead_mans_switch = FALSE;
 
@@ -773,7 +698,6 @@ picasa_post_upload_item (http_session_t session,
   picasa_post_clear_response_buffer ();
   g_free (url);
   g_free (auth);
-  g_free (length);
 
   return res;
 }
@@ -783,8 +707,7 @@ picasa_post_upload_item (http_session_t session,
   picasa_post_update_media
 */
 static picasa_post_response_t
-picasa_post_update_media (http_session_t session,
-			  gchar *tags,
+picasa_post_update_media (gchar *tags,
 			  gchar *gps,
 			  ConIcConnection *con,
 			  picasa_post_progress_data_t *data) {
@@ -826,30 +749,12 @@ picasa_post_update_media (http_session_t session,
 
   media = picasa_xml_create_media_entry (tags, gps);
 
-#if 0
-  media = g_strdup_printf ("<?xml version=\"1.0\"?>\n"
-			   "<entry xmlns=\"http://www.w3.org/2005/Atom\"\n"
-			   "xmlns:media=\"http://search.yahoo.com/mrss/\"\n"
-			   "xmlns:georss=\"http://www.georss.org/georss\"\n"
-			   "xmlns:gphoto=\"http://schemas.google.com/photos/2007\"\n"
-			   "xmlns:gml=\"http://www.opengis.net/gml\">\n"
-			   "<media:group>\n"
-			   "<media:keywords>tag, tag3</media:keywords>\n"
-			   "</media:group>\n"
-			   "<georss:where>\n"
-			   "<gml:Point>\n"
-			   "<gml:pos>35.669998 139.770004</gml:pos>\n"
-			   "</gml:Point>\n"
-			   "</georss:where>\n"
-			   "<category scheme=\"http://schemas.google.com/g/2005#kind\"\n"
-			   "term=\"http://schemas.google.com/photos/2007#photo\"/>"
-			   "</entry>\n");
-#endif
-
-  picasa_http_append_prefix (http, media);
-  length = g_strdup_printf("%d", http->prefix.data->len);
-  picasa_http_add_header_data (http, "Content-Length", length);
+  picasa_http_append_read_data (http, media);
   g_free (media);
+  
+  length = g_strdup_printf("%d", http->read_data.data->len);
+  picasa_http_add_header_data (http, "Content-Length", length);
+  g_free (length);
 
   picasa_post_init_response_buffer ();
   picasa_http_set_response_buffer (http,
@@ -859,9 +764,13 @@ picasa_post_update_media (http_session_t session,
   picasa_http_set_connection (http, con);
 
   ULOG_DEBUG_L ("%s: Sending post to %s", fn, g_photo_url);
+
   *data->dead_mans_switch = FALSE;
-  status = picasa_http_send (session, http, PUT);
+
+  status = picasa_http_send (http, PUT);
+
   *data->dead_mans_switch = FALSE;
+
   ULOG_DEBUG_L ("%s: sharing_http_request_send returned %d",fn,status);
 
   /* send successfully, check picasa response */
@@ -933,14 +842,12 @@ picasa_post_get_gps_coordinates (ConIcConnection *con,
 
   picasa_http_set_connection (http, con);
   
-  /* picasa_http_set_progress_cb (http, picasa_post_progress, data); */
-
   /* send http post */
   ULOG_DEBUG_L ("%s: Sending post", fn);
 
   *data->dead_mans_switch = FALSE;
 
-  status = picasa_http_send (NULL, http, GET);
+  status = picasa_http_send (http, GET);
 
   *data->dead_mans_switch = FALSE;
 
@@ -960,13 +867,12 @@ picasa_post_get_gps_coordinates (ConIcConnection *con,
   return res;
 }
 
-#if 0
+#ifdef WITH_ALBUM_SUPPORT
 /**
-  picasa_post_add_tags
+  picasa_post_add_tag
 */
 static picasa_post_response_t
-picasa_post_add_tag (http_session_t session, 
-		     gchar *tag,
+picasa_post_add_tag (gchar *tag,
 		     gint type,
 		     ConIcConnection *con,
 		     picasa_post_progress_data_t *data) {
@@ -1019,9 +925,11 @@ picasa_post_add_tag (http_session_t session,
   }
 
   picasa_http_append_prefix (http, tag_entry);
+  g_free (tag_entry);
+
   length = g_strdup_printf("%d", http->prefix.data->len);
   picasa_http_add_header_data (http, "Content-Length", length);
-  g_free (tag_entry);
+  g_free(length);
 
   picasa_post_init_response_buffer ();
   picasa_http_set_response_buffer (http,
@@ -1031,9 +939,13 @@ picasa_post_add_tag (http_session_t session,
   picasa_http_set_connection (http, con);
 
   ULOG_DEBUG_L ("%s: Sending post to %s", fn, g_photo_url);
+
   *data->dead_mans_switch = FALSE;
-  status = picasa_http_send (session, http, POST);
+
+  status = picasa_http_send (http, POST);
+
   *data->dead_mans_switch = FALSE;
+
   ULOG_DEBUG_L ("%s: sharing_http_request_send returned %d",fn,status);
 
   /* send successfully, check picasa response */
@@ -1049,15 +961,14 @@ picasa_post_add_tag (http_session_t session,
 
   return res;
 }
-#endif
+#endif /* WITH_ALBUM_SUPPORT */
 
 
 /**
    picasa_post_add_tags
 */
 static gint
-picasa_post_add_tags (http_session_t session,
-		      SharingEntryMedia *media,
+picasa_post_add_tags (SharingEntryMedia *media,
 		      ConIcConnection *con,
 		      picasa_post_progress_data_t *data) {
 #ifdef DEBUG
@@ -1097,10 +1008,7 @@ picasa_post_add_tags (http_session_t session,
 	}
 	
 	ULOG_DEBUG_L ("%s: found new tag = %s", fn, tag_str->str);
-	/*
-	  res = picasa_post_add_tag (session, (gchar*)tag_name, 
-	  NORMAL_TAG, con, data);
-	*/
+
 	break;
       }
 
@@ -1147,10 +1055,6 @@ picasa_post_add_tags (http_session_t session,
 	res.msg != NULL) {
       ULOG_DEBUG_L ("%s: found coordinate = %s", fn, res.msg);
       
-      /*
-	res = picasa_post_add_tag (session, res.msg, 
-	GPS_TAG, con, data);
-      */
     }
     
   }
@@ -1160,8 +1064,7 @@ picasa_post_add_tags (http_session_t session,
   /* if tags or coordinates to update */
   if (tags != NULL || res.msg != NULL) {
     ULOG_DEBUG_L ("%s: trying to update media entry", fn);
-    res = picasa_post_update_media (session, tags, res.msg,
-				    con, data);
+    res = picasa_post_update_media (tags, res.msg, con, data);
 
     ULOG_DEBUG_L ("%s: media entry updated with status = %d", fn, res.code);
   }
@@ -1169,7 +1072,9 @@ picasa_post_add_tags (http_session_t session,
   ULOG_DEBUG_L ("%s: leaving", fn);
 
   /* cleanup */
-  g_string_free (tag_str, TRUE);
+  if (tag_str != NULL) {
+    g_string_free (tag_str, TRUE);
+  }
   if (res.msg != NULL) { 
     g_free (res.msg); 
     res.msg = NULL;
@@ -1179,7 +1084,7 @@ picasa_post_add_tags (http_session_t session,
 }
 
 
-#if 0
+#ifdef WITH_ALBUM_SUPPORT
 /**
    picasa_post_update_albums
 */
@@ -1234,7 +1139,7 @@ picasa_post_update_albums (SharingAccount *account,
 
   return status;
 }
-#endif
+#endif /* WITH_ALBUM_SUPPORT */
 
 
 /*
@@ -1242,7 +1147,7 @@ picasa_post_update_albums (SharingAccount *account,
 */
 
 
-#if 0
+#ifdef WITH_ALBUM_SUPPORT
 /**
    picasa_post_update_options
 */
@@ -1285,16 +1190,16 @@ picasa_post_update_options (gpointer data) {
 
   return NULL;  
 }
-#endif
+#endif /* WITH_ALBUM_SUPPORT */
 
 /**
    picasa_post_validate_account
 */
 SharingPluginInterfaceAccountValidateResult
 picasa_post_validate_account (SharingAccount *account,
-			       ConIcConnection *con,
-			       gboolean *cont,
-			       gboolean *dead_mans_switch) {
+			      ConIcConnection *con,
+			      gboolean *cont,
+			      gboolean *dead_mans_switch) {
 
 #ifdef DEBUG
   gchar *fn = "picasa_post_validate_account()";
@@ -1304,8 +1209,8 @@ picasa_post_validate_account (SharingAccount *account,
 
   SharingPluginInterfaceAccountValidateResult
     status = SHARING_ACCOUNT_VALIDATE_FAILED;
-  picasa_post_response_t res = { 0, NULL };
 
+  picasa_post_response_t res = { 0, NULL };
   picasa_post_progress_data_t data;
 
   *dead_mans_switch = FALSE;
@@ -1319,16 +1224,13 @@ picasa_post_validate_account (SharingAccount *account,
   data.entry = NULL;
   data.request = NULL;
 
-  http_session_t session = picasa_http_init ();
-
   ULOG_DEBUG_L ("%s: LOGIN",fn);  
 
   /* login to validate */
-  res = picasa_post_login (session, con, &data);
+  res = picasa_post_login (con, &data);
 
   status = picasa_post_convert_validate_response (res);
 
-  picasa_http_uninit (session);
   picasa_post_free_globals ();
 
   return status;
@@ -1340,8 +1242,8 @@ picasa_post_validate_account (SharingAccount *account,
 */
 SharingPluginInterfaceSendResult 
 picasa_post_upload_to_service (SharingTransfer *transfer,
-			      ConIcConnection *con,
-			      gboolean *dead_mans_switch) {
+			       ConIcConnection *con,
+			       gboolean *dead_mans_switch) {
 
 #ifdef DEBUG
   gchar *fn = "picasa_post_upload_to_service()";
@@ -1371,30 +1273,15 @@ picasa_post_upload_to_service (SharingTransfer *transfer,
 
   *dead_mans_switch = FALSE;
   
-  http_session_t session = NULL; /* picasa_http_init (); */
-
   ULOG_DEBUG_L ("%s: LOGIN",fn);
 
-  res = picasa_post_login (session, con, &data);
+  res = picasa_post_login (con, &data);
   
   if (res.code != HTTP_OK) {
     ULOG_DEBUG_L ("%s: login failed %d", fn, res.code);
     return picasa_post_convert_send_response (res);
   }
 
-  /* do we want to update album list every time new upload
-     is started?? */
-#if 0
-  ULOG_DEBUG_L ("%s: FETCH ALBUMS",fn);
-
-  res = picasa_post_get_albums (session, con, &data);
-
-  if (status != 0) {
-    ULOG_DEBUG_L ("%s: fetch albums failed %d",fn,status);
-    return picasa_post_convert_send_response (res);
-  } 
-#endif
-
   /* post all items in loop */
   for (m = sharing_entry_get_media(data.entry); 
        m != NULL; m = g_slist_next(m)) {
@@ -1405,14 +1292,13 @@ picasa_post_upload_to_service (SharingTransfer *transfer,
 
       ULOG_DEBUG_L ("%s: UPLOAD ITEM",fn);
 
-      res = picasa_post_upload_item (session, media, con, &data);
+      res = picasa_post_upload_item (media, con, &data);
       if (res.code == HTTP_OK || res.code == HTTP_CREATED) {
 	data.uploaded_size += sharing_entry_media_get_size (media);
 	sharing_entry_media_set_sent (media, TRUE);
 	/* try to update the tags */
 	ULOG_DEBUG_L ("%s: UPDATE TAGS", fn);
-	picasa_post_add_tags (session, media, con, &data);
-	/* ULOG_DEBUG_L ("%s: tags updated with status = %d", fn, status); */
+	picasa_post_add_tags (media, con, &data);
 	status = SHARING_SEND_SUCCESS;
       } else {
 	ULOG_DEBUG_L ("%s: sending to service failed %d",fn,status);
@@ -1420,10 +1306,8 @@ picasa_post_upload_to_service (SharingTransfer *transfer,
 	break;
       }
     }
-    
   }
 
-  /* picasa_http_uninit (session); */
   picasa_post_free_globals ();
 
   return status;
